==> con900_0.0.8-3.tar.gz: con900-0.0.8/CON900GUI.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 2 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
# Project:Customize-OptimizeN900 GUI
# Author:humble

import pygtk
pygtk.require('2.0')
import gtk
import os
import time

class GUI:

    def Find_Process(self, widget):
        os.system("top -b -n 1 > /home/findump.txt")
        time.sleep(1)
        os.system( "python /home/opt/CON900/Found")

    def Restore_script(self, messagedialog):
        messagedialog = gtk.MessageDialog(self.window, 0, gtk.MESSAGE_QUESTION, gtk.BUTTONS_YES_NO, "Are You Sure You Want To Restore Your OptimizeN900 Script?")
        response = messagedialog.run()
        messagedialog.destroy()
        
        if response == gtk.RESPONSE_YES :
            Restored = open('/usr/local/bin/OptimizeN900', 'w')
	    Restored.write('#!/bin/sh')
	    Restored.write('\necho Your Nokia N900 is being Optimized')
	    Restored.write('\nkillall trackerd')
	    Restored.write('\nkillall tracker-indexer')
	    Restored.write('\nkillall browser browserd')
	    Restored.write('\nkillall Calendar')
	    Restored.write('\nkillall osso_calculator')
	    Restored.write('\nkillall camera-ui')
	    Restored.write('\nkillall modest')
	    Restored.write('\nkillall rtcom-messaging-ui')
	    Restored.write('\nkillall image-viewer')
	    Restored.write('\nkillall osso_notes')
	    Restored.write('\nkillall osso-addressbook')
	    Restored.write('\n#killall hildon-desktop')
	    Restored.write('\nkillall hildon-status-menu')
	    Restored.write('\nkillall systemui')
	    Restored.write('\nkillall tonegend')
	    Restored.write('\nkillall mafw-gst-renderer')
	    Restored.write('\n')
	    Restored.close()
        elif response == gtk.RESPONSE_NO :
            pass
            
    def Edit_Script(self, messagedialog):
        messagedialog = gtk.MessageDialog(self.window, 0, gtk.MESSAGE_QUESTION, gtk.BUTTONS_YES_NO, "Are You Sure You Want To Edit Your OptimizeN900 Script?")
        response = messagedialog.run()
        messagedialog.destroy()
        
        if response == gtk.RESPONSE_YES :
            os.system( "python /home/opt/CON900/Edit")
        elif response == gtk.RESPONSE_NO :
            pass
            
    def delete_event(self, widget, event):
        gtk.main_quit()
        return False
        
    def __init__(self):

        self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
        self.window.set_title("CON900")

        self.window.connect("delete_event", self.delete_event)

        self.window.set_border_width(5)
        self.window.set_default_size(800, 480)
        
        aboutdialog = gtk.AboutDialog()        
        aboutdialog.set_name("CON900")
        aboutdialog.set_version("0.0.8-3")
        aboutdialog.set_comments("This application was created to ease the customization of OptimizeN900 Script. It's coded in PyGTK.")
        aboutdialog.set_license("GNU LGPL 2.1")
        aboutdialog.set_website("http://www.maemo.org/")
        aboutdialog.set_authors(["humble"])

        aboutdialog.run()
        aboutdialog.destroy()
        

        table = gtk.Table(3, 3, True)
        self.window.add(table)


        button = gtk.Button("Find")
        button.connect("clicked", self.Find_Process)
        table.attach(button, 0, 1, 1, 2)

	button = gtk.Button("Edit")
        button.connect("clicked", self.Edit_Script)
        table.attach(button, 1, 2, 1, 2)

        button = gtk.Button("Restore")
        button.connect("clicked", self.Restore_script)
        table.attach(button, 2, 3, 1, 2)

	button = gtk.Button("Quit")
	button.connect("clicked", lambda w: gtk.main_quit())
	table.attach(button, 0, 3, 2, 3)

        self.window.show_all()

def main():
    gtk.main()
    return 0       

if __name__ == "__main__":
    GUI()
    main()

==> con900_0.0.8-4.tar.gz: con900-0.0.8/CON900GUI.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 2 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
# Project:Customize-OptimizeN900 GUI
# Author:humble

import pygtk
pygtk.require('2.0')
import gtk
import os
import time

class GUI:

    def Find_Process(self, widget):
        os.system("top -b -n 1 > /home/findump.txt")
        time.sleep(1)
        os.system( "python /home/opt/CON900/Found")

    def Restore_script(self, messagedialog):
        messagedialog = gtk.MessageDialog(self.window, 0, gtk.MESSAGE_QUESTION, gtk.BUTTONS_YES_NO, "Are You Sure You Want To Restore Your OptimizeN900 Script?")
        response = messagedialog.run()
        messagedialog.destroy()
        
        if response == gtk.RESPONSE_YES :
            Restored = open('/usr/local/bin/OptimizeN900', 'w')
	    Restored.write('#!/bin/sh')
	    Restored.write('\necho Your Nokia N900 is being Optimized')
	    Restored.write('\nkillall trackerd')
	    Restored.write('\nkillall tracker-indexer')
	    Restored.write('\nkillall browser browserd')
	    Restored.write('\nkillall Calendar')
	    Restored.write('\nkillall osso_calculator')
	    Restored.write('\nkillall camera-ui')
	    Restored.write('\nkillall modest')
	    Restored.write('\nkillall rtcom-messaging-ui')
	    Restored.write('\nkillall image-viewer')
	    Restored.write('\nkillall osso_notes')
	    Restored.write('\nkillall osso-addressbook')
	    Restored.write('\n#killall hildon-desktop')
	    Restored.write('\nkillall hildon-status-menu')
	    Restored.write('\nkillall systemui')
	    Restored.write('\nkillall tonegend')
	    Restored.write('\nkillall mafw-gst-renderer')
	    Restored.write('\n')
	    Restored.close()
        elif response == gtk.RESPONSE_NO :
            pass
            
    def Edit_Script(self, messagedialog):
        messagedialog = gtk.MessageDialog(self.window, 0, gtk.MESSAGE_QUESTION, gtk.BUTTONS_YES_NO, "Are You Sure You Want To Edit Your OptimizeN900 Script?")
        response = messagedialog.run()
        messagedialog.destroy()
        
        if response == gtk.RESPONSE_YES :
            os.system( "sudo python /home/opt/CON900/Edit")
        elif response == gtk.RESPONSE_NO :
            pass
            
    def delete_event(self, widget, event):
        gtk.main_quit()
        return False
        
    def __init__(self):

        self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
        self.window.set_title("CON900")

        self.window.connect("delete_event", self.delete_event)

        self.window.set_border_width(5)
        self.window.set_default_size(800, 480)
        
        aboutdialog = gtk.AboutDialog()        
        aboutdialog.set_name("CON900")
        aboutdialog.set_version("0.0.8-4")
        aboutdialog.set_comments("This application was created to ease the customization of OptimizeN900 Script. It's coded in PyGTK.")
        aboutdialog.set_license("GNU LGPL 2.1")
        aboutdialog.set_website("humblecon900.garage.maemo.org")
        aboutdialog.set_authors(["humble"])

        aboutdialog.run()
        aboutdialog.destroy()
        

        table = gtk.Table(3, 3, True)
        self.window.add(table)


        button = gtk.Button("Find")
        button.connect("clicked", self.Find_Process)
        table.attach(button, 0, 1, 1, 2)

	button = gtk.Button("Edit")
        button.connect("clicked", self.Edit_Script)
        table.attach(button, 1, 2, 1, 2)

        button = gtk.Button("Restore")
        button.connect("clicked", self.Restore_script)
        table.attach(button, 2, 3, 1, 2)

	button = gtk.Button("Quit")
	button.connect("clicked", lambda w: gtk.main_quit())
	table.attach(button, 0, 3, 2, 3)

        self.window.show_all()

def main():
    gtk.main()
    return 0       

if __name__ == "__main__":
    GUI()
    main()
